@@ -4,6 +4,7 @@
 
 mod async_read_utility;
 mod async_write_utility;
+mod io_slice_ext;
 
 #[cfg(feature = "mpsc")]
 #[cfg_attr(docsrs, doc(cfg(feature = "mpsc")))]
@@ -11,3 +12,4 @@ pub mod queue;
 
 pub use async_read_utility::*;
 pub use async_write_utility::write_vectored_all;
+pub use io_slice_ext::{IoSliceExt, IoSliceMutExt};
